diff --git a/AUTHORS b/AUTHORS
index 12f61590669f96e6a5ac279fc5246bcb7ef1e130..7c54c71ebe22bab91d8fd7dfccabf1032062fc90 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -35,3 +35,9 @@ David Benbennick <dbenbenn@math.cornell.edu>
 	* Wrap and justify bugfixes/enhancements, new color syntax
 	  code, memleak fixes, parts of the UTF-8 support, and other
 	  miscellaneous fixes.
+
+Mike Frysinger <vapier@gentoo.org>
+	* Gentoo package maintainer.  Whitespace display mode,
+	  --enable-utf8/--disable-utf8 configure options for ncurses,
+	  many new color regexes and improvements to existing color
+	  regexes for nanorc.sample, and miscellaneous bug fixes.
diff --git a/ChangeLog b/ChangeLog
index e824181eb347d5de700cc47aeb0d0698bbea4489..80736cdd704ce6d5ae8c21e0a24dd474a5ffd154 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -338,6 +338,7 @@ CVS code -
 	  tweak where screen updates occur so that messages are properly
 	  displayed when they first scroll onto the bottom line of the
 	  screen. (DLR)
+	- Add Mike Frysinger to credits. (DLR)
 - configure.ac:
 	- Since we only use vsnprintf() now, remove the tests for
 	  snprintf(). (DLR)
@@ -357,6 +358,8 @@ CVS code -
 	- Updated translation by Jean-Philippe Guérard.
 - src/Makefile.am:
 	- Add text.c to nano_SOURCES. (DLR)
+- AUTHORS:
+	- Add Mike Frysinger. (DLR)
 - THANKS:
 	- Add Bulgarian and Dutch translators.
 
diff --git a/src/winio.c b/src/winio.c
index 6ebe97cb21ef308b179c4e28454958c1e99a81d6..26daaf4a2d3dac1a7b5cc6b5e6f04c23c57d21e6 100644
--- a/src/winio.c
+++ b/src/winio.c
@@ -4202,9 +4202,10 @@ void do_credits(void)
 	"Rocco Corsi",
 	"David Lawrence Ramsey",
 	"David Benbennick",
+	"Mike Frysinger",
 	"Ken Tyler",
 	"Sven Guckes",
-	NULL,				/* credits[14], handled below. */
+	NULL,				/* credits[15], handled below. */
 	"Pauli Virtanen",
 	"Daniele Medri",
 	"Clement Laforet",
@@ -4256,10 +4257,10 @@ void do_credits(void)
 	N_("Thank you for using nano!")
     };
 
     /* credits[14]: Make sure this name is displayed properly, since we
      * can't dynamically assign it above, using Unicode 00F6 (Latin
      * Small Letter O with Diaresis) if applicable. */
-    credits[14] =
+    credits[15] =
 #ifdef ENABLE_UTF8
 	 ISSET(USE_UTF8) ? "Florian K\xC3\xB6nig" :
 #endif
@@ -4256,10 +4257,10 @@ void do_credits(void)
     };
 
-    /* credits[14]: Make sure this name is displayed properly, since we
+    /* credits[15]: Make sure this name is displayed properly, since we
      * can't dynamically assign it above, using Unicode 00F6 (Latin
      * Small Letter O with Diaresis) if applicable. */